## [0.1.0a6] - 2026-01-20

### 🚀 Features

- Implement core orchestration layer and client proxies (#7)

### ⚙️ Miscellaneous Tasks

- Refactor of detectors into namespaces (#6)
## [0.1.0a5] - 2026-01-16

### 🚀 Features

- Add language detection feature (#5)

### ⚙️ Miscellaneous Tasks

- Refactor into new structure and add better tests (#4)
- Update links
- Prepare release 0.1.0a5
## [0.1.0a4] - 2026-01-13

### 🚀 Features

- Rename property to threat_detected in DetectionResult

### ⚙️ Miscellaneous Tasks

- Improve workflow
- Prepare v0.1.0a4
## [0.1.0a3] - 2026-01-06

### 📚 Documentation

- Fix badges

### ⚙️ Miscellaneous Tasks

- Fix warning for init commit message
- Prepare v0.1.0a3
## [0.1.0a2] - 2026-01-06

### 🐛 Bug Fixes

- Export classes and bump version (#2)

### ⚙️ Miscellaneous Tasks

- Add summary step (#3)
- Prepare v0.1.0a2
## [0.1.0a1] - 2026-01-05

### 🚀 Features

- Init commit
- Add canary token feature

### ⚙️ Miscellaneous Tasks

- Finalize release workflow
- Update version
- Update workflow
- Prepare release
